@@ -10,6 +10,7 @@ from numpy import (
     all,
     abs as np_abs,
     interp,
+    where,
 )
 from scipy.interpolate import interp1d
 
@@ -85,13 +86,17 @@ def get_interpolation(values, axis_values, new_axis_values, index):
     ):  # Same axes -> no interpolation
         return values
     elif isin(
-        around(new_axis_values, 5), around(axis_values, 5)
+        new_axis_values, axis_values
     ).all():  # New axis is subset -> no interpolation
+
+        indice_take = where(isin(axis_values, new_axis_values))[0]
+
         return take(
             values,
-            [isin(around(axis_values, 5), around(new_axis_values, 5))],
+            indice_take,
             axis=index,
         )
+
     else:
         f = interp1d(axis_values, values, axis=index, fill_value="extrapolate")
         return f(new_axis_values)
@@ -121,9 +126,9 @@ def get_interpolation_step(values, axis_values, new_axis_values):
     ):  # Same axes -> no interpolation
         return values
     elif isin(
-        around(new_axis_values, 5), around(axis_values, 5)
+        new_axis_values, axis_values
     ).all():  # New axis is subset -> no interpolation
-        return values[isin(around(axis_values, 5), around(new_axis_values, 5))]
+        return values[isin(axis_values, new_axis_values)]
     else:
         if len(axis_values) == 1:
             return array([values[0] for i in range(len(new_axis_values))])
