@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from numpy import sum as np_sum, sqrt
+from numpy import sum as np_sum, mean as np_mean, sqrt
 from SciDataTool.Functions.symmetries import rebuild_symmetries
 
 
@@ -29,10 +29,18 @@ def get_field(self, axes_list):
             values = rebuild_symmetries(values, axis_requested.index, axis_symmetries)
             axis_symmetries["antiperiod"] = nper
 
-        # Sum over sum axes
+        # sum over sum axes
         if axis_requested.extension == "sum":
             values = np_sum(values, axis=axis_requested.index, keepdims=True)
-        # RMS over sum axes
-        elif axis_requested.extension == "rms":
+        # root sum square over rss axes
+        elif axis_requested.extension == "rss":
             values = sqrt(np_sum(values ** 2, axis=axis_requested.index, keepdims=True))
+        # mean value over mean axes
+        elif axis_requested.extension == "mean":
+            values = np_mean(values, axis=axis_requested.index, keepdims=True)
+        # RMS over rms axes
+        elif axis_requested.extension == "rms":
+            values = sqrt(
+                np_mean(values ** 2, axis=axis_requested.index, keepdims=True)
+            )
     return values
